For consistency reasons, spell the controller name as "LINFlexD" in
comments and documentation.

Signed-off-by: Stefan-Gabriel Mirea <stefan-gabriel.mi...@nxp.com>
---
 Documentation/admin-guide/kernel-parameters.txt | 2 +-
 drivers/tty/serial/Kconfig                      | 8 ++++----
 drivers/tty/serial/fsl_linflexuart.c            | 4 ++--
 include/uapi/linux/serial_core.h                | 4 ++--
 4 files changed, 9 insertions(+), 9 deletions(-)

diff --git a/Documentation/admin-guide/kernel-parameters.txt 
b/Documentation/admin-guide/kernel-parameters.txt
index 614012a61754..23162492ea2f 100644
--- a/Documentation/admin-guide/kernel-parameters.txt
+++ b/Documentation/admin-guide/kernel-parameters.txt
@@ -1091,7 +1091,7 @@
                        mapped with the correct attributes.
 
                linflex,<addr>
-                       Use early console provided by Freescale LinFlex UART
+                       Use early console provided by Freescale LINFlexD UART
                        serial driver for NXP S32V234 SoCs. A valid base
                        address must be provided, and the serial port must
                        already be setup and configured.
diff --git a/drivers/tty/serial/Kconfig b/drivers/tty/serial/Kconfig
index b658589208bf..2d5115375345 100644
--- a/drivers/tty/serial/Kconfig
+++ b/drivers/tty/serial/Kconfig
@@ -1434,19 +1434,19 @@ config SERIAL_FSL_LPUART_CONSOLE
          you can make it the console by answering Y to this option.
 
 config SERIAL_FSL_LINFLEXUART
-       tristate "Freescale linflexuart serial port support"
+       tristate "Freescale LINFlexD UART serial port support"
        depends on PRINTK
        select SERIAL_CORE
        help
-         Support for the on-chip linflexuart on some Freescale SOCs.
+         Support for the on-chip LINFlexD UART on some Freescale SOCs.
 
 config SERIAL_FSL_LINFLEXUART_CONSOLE
-       bool "Console on Freescale linflexuart serial port"
+       bool "Console on Freescale LINFlexD UART serial port"
        depends on SERIAL_FSL_LINFLEXUART=y
        select SERIAL_CORE_CONSOLE
        select SERIAL_EARLYCON
        help
-         If you have enabled the linflexuart serial port on the Freescale
+         If you have enabled the LINFlexD UART serial port on the Freescale
          SoCs, you can make it the console by answering Y to this option.
 
 config SERIAL_CONEXANT_DIGICOLOR
diff --git a/include/uapi/linux/serial_core.h b/include/uapi/linux/serial_core.h
index 63fa56b899e8..26967c2f4a4f 100644
--- a/include/uapi/linux/serial_core.h
+++ b/include/uapi/linux/serial_core.h
@@ -293,7 +293,7 @@
 /* Sunix UART */
 #define PORT_SUNIX     121
 
-/* Freescale Linflex UART */
-#define PORT_LINFLEXUART       121
+/* Freescale LINFlexD UART */
+#define PORT_LINFLEXUART       122
 
 #endif /* _UAPILINUX_SERIAL_CORE_H */
diff --git a/drivers/tty/serial/fsl_linflexuart.c 
b/drivers/tty/serial/fsl_linflexuart.c
index 26b9601a0952..ca90551384ca 100644
--- a/drivers/tty/serial/fsl_linflexuart.c
+++ b/drivers/tty/serial/fsl_linflexuart.c
@@ -1,6 +1,6 @@
 // SPDX-License-Identifier: GPL-2.0-or-later
 /*
  * Freescale linflexuart serial port driver
  *
  * Copyright 2012-2016 Freescale Semiconductor, Inc.
  * Copyright 2017-2018 NXP
@@ -938,5 +938,5 @@ static void __exit linflex_serial_exit(void)
 module_init(linflex_serial_init);
 module_exit(linflex_serial_exit);
 
-MODULE_DESCRIPTION("Freescale linflex serial port driver");
+MODULE_DESCRIPTION("Freescale LINFlexD serial port driver");
 MODULE_LICENSE("GPL v2");
@@ -1,6 +1,6 @@
 // SPDX-License-Identifier: GPL-2.0-or-later
 /*
- * Freescale linflexuart serial port driver
+ * Freescale LINFlexD UART serial port driver
  *
  * Copyright 2012-2016 Freescale Semiconductor, Inc.
-- 
2.22.0

Reply via email to